@@ -1,6 +1,6 @@
 import sys
 from practicejapanese import __version__ as VERSION
-from practicejapanese.quizzes import vocab_quiz, kanji_quiz, filling_quiz
+from practicejapanese.quizzes import audio_quiz, vocab_quiz, kanji_quiz
 from practicejapanese.core.quiz_runner import random_quiz
 from practicejapanese.core.dev_mode import run_dev_mode
 import os
@@ -19,7 +19,8 @@ def main():
     print("2. Vocab Quiz")
     print("3. Kanji Quiz")
     print("4. Kanji Fill-in Quiz")
-    print("5. Reset all scores to zero")
+    print("5. Audio Quiz")
+    print("6. Reset all scores to zero")
     choice = input("Enter number: ").strip()
     try:
         if choice == "1":
@@ -31,9 +32,13 @@ def main():
             kanji_quiz.run()
             print()  # Add empty line after each question
         elif choice == "4":
+            from practicejapanese.quizzes import filling_quiz
             filling_quiz.run()
             print()  # Add empty line after each question
         elif choice == "5":
+            audio_quiz.run()
+            print()  # Add empty line after each question
+        elif choice == "6":
             from practicejapanese.core.utils import reset_scores
             reset_scores()
         else:
